# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import any_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.eventarc.publishing.v1",
    manifest={
        "CloudEvent",
    },
)


class CloudEvent(proto.Message):
    r"""CloudEvent represents a vendor-neutral specification for
    defining the format of event data.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        id (str):
            Required. Identifies the event. Producers
            MUST ensure that source + id is unique for each
            distinct event.
        source (str):
            Required. Identifies the context in which an
            event happened. URI-reference
        spec_version (str):
            Required. The version of the CloudEvents
            specification which the event uses.
        type_ (str):
            Required. This attribute contains a value
            describing the type of event related to the
            originating occurrence.
        attributes (MutableMapping[str, google.cloud.eventarc_publishing_v1.types.CloudEvent.CloudEventAttributeValue]):
            Optional. Used for Optional & Extension
            Attributes
        binary_data (bytes):
            Optional. Binary data.

            This field is a member of `oneof`_ ``data``.
        text_data (str):
            Optional. Text data.

            This field is a member of `oneof`_ ``data``.
        proto_data (google.protobuf.any_pb2.Any):
            Optional. Proto data.

            NOTE: The ``protoData`` field only functions as expected
            when the payload is specifically a ``CloudEvent`` message
            type, and can't be used for arbitrary protocol buffer
            messages. For any other protocol buffer type, you must
            serialize your proto message into bytes, and use the
            ``binaryData`` field instead.

            This field is a member of `oneof`_ ``data``.
    """

    class CloudEventAttributeValue(proto.Message):
        r"""The following abstract data types are available for use in
        attributes.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            ce_boolean (bool):
                Boolean value.

                This field is a member of `oneof`_ ``attr``.
            ce_integer (int):
                Integer value.

                This field is a member of `oneof`_ ``attr``.
            ce_string (str):
                String value.

                This field is a member of `oneof`_ ``attr``.
            ce_bytes (bytes):
                Bytes value.

                This field is a member of `oneof`_ ``attr``.
            ce_uri (str):
                URI value.

                This field is a member of `oneof`_ ``attr``.
            ce_uri_ref (str):
                URI-reference value.

                This field is a member of `oneof`_ ``attr``.
            ce_timestamp (google.protobuf.timestamp_pb2.Timestamp):
                Timestamp value.

                This field is a member of `oneof`_ ``attr``.
        """

        ce_boolean: bool = proto.Field(
            proto.BOOL,
            number=1,
            oneof="attr",
        )
        ce_integer: int = proto.Field(
            proto.INT32,
            number=2,
            oneof="attr",
        )
        ce_string: str = proto.Field(
            proto.STRING,
            number=3,
            oneof="attr",
        )
        ce_bytes: bytes = proto.Field(
            proto.BYTES,
            number=4,
            oneof="attr",
        )
        ce_uri: str = proto.Field(
            proto.STRING,
            number=5,
            oneof="attr",
        )
        ce_uri_ref: str = proto.Field(
            proto.STRING,
            number=6,
            oneof="attr",
        )
        ce_timestamp: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=7,
            oneof="attr",
            message=timestamp_pb2.Timestamp,
        )

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    source: str = proto.Field(
        proto.STRING,
        number=2,
    )
    spec_version: str = proto.Field(
        proto.STRING,
        number=3,
    )
    type_: str = proto.Field(
        proto.STRING,
        number=4,
    )
    attributes: MutableMapping[str, CloudEventAttributeValue] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=5,
        message=CloudEventAttributeValue,
    )
    binary_data: bytes = proto.Field(
        proto.BYTES,
        number=6,
        oneof="data",
    )
    text_data: str = proto.Field(
        proto.STRING,
        number=7,
        oneof="data",
    )
    proto_data: any_pb2.Any = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="data",
        message=any_pb2.Any,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.eventarc_publishing_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.publisher import PublisherAsyncClient, PublisherClient
from .types.cloud_event import CloudEvent
from .types.publisher import (
    PublishChannelConnectionEventsRequest,
    PublishChannelConnectionEventsResponse,
    PublishEventsRequest,
    PublishEventsResponse,
    PublishRequest,
    PublishResponse,
)

__all__ = (
    "PublisherAsyncClient",
    "CloudEvent",
    "PublishChannelConnectionEventsRequest",
    "PublishChannelConnectionEventsResponse",
    "PublishEventsRequest",
    "PublishEventsResponse",
    "PublishRequest",
    "PublishResponse",
    "PublisherClient",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import any_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.eventarc_publishing_v1.types import cloud_event

__protobuf__ = proto.module(
    package="google.cloud.eventarc.publishing.v1",
    manifest={
        "PublishChannelConnectionEventsRequest",
        "PublishChannelConnectionEventsResponse",
        "PublishEventsRequest",
        "PublishEventsResponse",
        "PublishRequest",
        "PublishResponse",
    },
)


class PublishChannelConnectionEventsRequest(proto.Message):
    r"""The request message for the PublishChannelConnectionEvents
    method.

    Attributes:
        channel_connection (str):
            The channel_connection that the events are published from.
            For example:
            ``projects/{partner_project_id}/locations/{location}/channelConnections/{channel_connection_id}``.
        events (MutableSequence[google.protobuf.any_pb2.Any]):
            The CloudEvents v1.0 events to publish. No other types are
            allowed. If this field is set, then the ``text_events``
            fields must not be set.
        text_events (MutableSequence[str]):
            The text representation of events to publish. CloudEvent
            v1.0 in JSON format is the only allowed type. Refer to
            https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/json-format.md
            for specification. If this field is set, then the ``events``
            fields must not be set.
    """

    channel_connection: str = proto.Field(
        proto.STRING,
        number=1,
    )
    events: MutableSequence[any_pb2.Any] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=any_pb2.Any,
    )
    text_events: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class PublishChannelConnectionEventsResponse(proto.Message):
    r"""The response message for the PublishChannelConnectionEvents
    method.

    """


class PublishEventsRequest(proto.Message):
    r"""The request message for the PublishEvents method.

    Attributes:
        channel (str):
            The full name of the channel to publish to. For example:
            ``projects/{project}/locations/{location}/channels/{channel-id}``.
        events (MutableSequence[google.protobuf.any_pb2.Any]):
            The CloudEvents v1.0 events to publish. No other types are
            allowed. If this field is set, then the ``text_events``
            fields must not be set.
        text_events (MutableSequence[str]):
            The text representation of events to publish. CloudEvent
            v1.0 in JSON format is the only allowed type. Refer to
            https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/json-format.md
            for specification. If this field is set, then the ``events``
            fields must not be set.
    """

    channel: str = proto.Field(
        proto.STRING,
        number=1,
    )
    events: MutableSequence[any_pb2.Any] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=any_pb2.Any,
    )
    text_events: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class PublishEventsResponse(proto.Message):
    r"""The response message for the PublishEvents method."""


class PublishRequest(proto.Message):
    r"""The request message for the Publish method.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        message_bus (str):
            Required. The full name of the message bus to publish events
            to. Format:
            ``projects/{project}/locations/{location}/messageBuses/{messageBus}``.
        proto_message (google.cloud.eventarc_publishing_v1.types.CloudEvent):
            The Protobuf format of the CloudEvent being
            published. Specification can be found here:

            https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/protobuf-format.md

            This field is a member of `oneof`_ ``format``.
        json_message (str):
            The JSON format of the CloudEvent being
            published. Specification can be found here:

            https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/json-format.md

            This field is a member of `oneof`_ ``format``.
        avro_message (bytes):
            The Avro format of the CloudEvent being
            published. Specification can be found here:

            https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/avro-format.md

            This field is a member of `oneof`_ ``format``.
    """

    message_bus: str = proto.Field(
        proto.STRING,
        number=1,
    )
    proto_message: cloud_event.CloudEvent = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="format",
        message=cloud_event.CloudEvent,
    )
    json_message: str = proto.Field(
        proto.STRING,
        number=3,
        oneof="format",
    )
    avro_message: bytes = proto.Field(
        proto.BYTES,
        number=4,
        oneof="format",
    )


class PublishResponse(proto.Message):
    r"""The response message for the Publish method."""


__all__ = tuple(sorted(__protobuf__.manifest))
